==> haskell-template-haskell-compat-v0208-0.1.9.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-template-haskell-compat-v0208.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 template-haskell-compat-v0208
version:              0.1.9.2
visibility:           public
id:
    template-haskell-compat-v0208-0.1.9.2-7QuGd69Nysp590aYJ6z7Ut

key:
    template-haskell-compat-v0208-0.1.9.2-7QuGd69Nysp590aYJ6z7Ut

license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:
    https://github.com/nikita-volkov/template-haskell-compat-v0208

synopsis:
    A backwards compatibility layer for Template Haskell newer than 2.8

category:             TemplateHaskell, Compatibility
abi:                  fac58c3448e173e21a29d749b68ffb31
exposed:              True
exposed-modules:      TemplateHaskell.Compat.V0208
hidden-modules:       TemplateHaskell.Compat.V0208.Prelude
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/template-haskell-compat-v0208-0.1.9.2

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/template-haskell-compat-v0208-0.1.9.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-template-haskell-compat-v0208
hs-libraries:
    HStemplate-haskell-compat-v0208-0.1.9.2-7QuGd69Nysp590aYJ6z7Ut

depends:              base-4.15.1.0 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-template-haskell-compat-v0208/html/template-haskell-compat-v0208.haddock

haddock-html:         /usr/share/doc/haskell-template-haskell-compat-v0208/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-template-haskell-compat-v0208-0.1.9.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-template-haskell-compat-v0208.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 template-haskell-compat-v0208
version:              0.1.9.3
visibility:           public
id:
    template-haskell-compat-v0208-0.1.9.3-4UHEX7s6iYxJjRg0WVhAg2

key:
    template-haskell-compat-v0208-0.1.9.3-4UHEX7s6iYxJjRg0WVhAg2

license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:
    https://github.com/nikita-volkov/template-haskell-compat-v0208

synopsis:
    Backward-compatibility layer for Template Haskell newer than 2.8

description:
    Collection of functions that aims to help you to write
    Template Haskell that is compatible
    with all versions of GHC starting from 7.6.
    The oldest GHC serves as the common denominator here,
    so the newer functionality is avoided here.

category:             TemplateHaskell, Compatibility
abi:                  55a7ae4b3fc6601d7db225fbac8eebfa
exposed:              True
exposed-modules:      TemplateHaskell.Compat.V0208
hidden-modules:       TemplateHaskell.Compat.V0208.Prelude
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/template-haskell-compat-v0208-0.1.9.3

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/template-haskell-compat-v0208-0.1.9.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-template-haskell-compat-v0208
hs-libraries:
    HStemplate-haskell-compat-v0208-0.1.9.3-4UHEX7s6iYxJjRg0WVhAg2

depends:              base-4.15.1.0 template-haskell-2.17.0.0
haddock-interfaces:
    /usr/share/doc/haskell-template-haskell-compat-v0208/html/template-haskell-compat-v0208.haddock

haddock-html:         /usr/share/doc/haskell-template-haskell-compat-v0208/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
